//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[UnionShantenResult](index.md)/[UnionShantenResult](-union-shanten-result.md)

# UnionShantenResult

[common]\
constructor(hand: [Hand](../../mahjongutils.models.hand/-hand/index.md)&lt;[CommonHandPattern](../../mahjongutils.models.hand/-common-hand-pattern/index.md)&gt;, shantenInfo: [CommonShanten](../-common-shanten/index.md), regular: [RegularShantenResult](../-regular-shanten-result/index.md), chitoi: [ChitoiShantenResult](../-chitoi-shanten-result/index.md)? = null, kokushi: [KokushiShantenResult](../-kokushi-shanten-result/index.md)? = null)
